EntityData class

Identifies a single entity in the loaded 3D model.

Constructors

EntityData({required int id, required String name})

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
Filament entity ID (Android) or SceneKit hash (iOS).
final
name String
Node name as defined in the glTF/GLB file.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited